#
# spec file for package alex
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%bcond_without tests
Name:           alex
Version:        3.1.7
Release:        12.16
Summary:        Alex is a tool for generating lexical analysers in Haskell
License:        BSD-3-Clause
Group:          Development/Languages/Other
Url:            https://hackage.haskell.org/package/%{name}
Source0:        https://hackage.haskell.org/package/%{name}-%{version}/%{name}-%{version}.tar.gz
BuildRequires:  autoconf
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-QuickCheck-devel
BuildRequires:  ghc-array-devel
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-directory-devel
BuildRequires:  ghc-rpm-macros
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if %{with tests}
BuildRequires:  ghc-process-devel
%endif

%description
Alex is a tool for generating lexical analysers in Haskell. It takes a
description of tokens based on regular expressions and generates a Haskell
module containing code for scanning text efficiently. It is similar to the tool
lex or flex for C/C++.

%prep
%setup -q

%build
%ghc_bin_build
cd doc
test -f configure || autoreconf
# FIXME: you should use the %%configure macro
./configure

%install
%ghc_bin_install
mkdir -p %{buildroot}/%{_mandir}/man1
cp doc/alex.1 %{buildroot}/%{_mandir}/man1

%check
%cabal_test

%files
%defattr(-,root,root,-)
%doc LICENSE
%doc CHANGELOG.md README TODO doc examples
%{_bindir}/%{name}
%{_datadir}/%{name}-%{version}
%{_mandir}/man1/*

%changelog
* Sun Jul 10 2016 psimons@suse.com
- Update to version 3.1.7 revision 0 with cabal2obs.
* Mon Jan 11 2016 mimi.vx@gmail.com
- update to 3.1.7
  * Add support for %%encoding directive (allows to control --latin1 from inside
    Alex scripts)
  * Make code forward-compatible with in-progress proposals
  * Suppress more warnings
* Mon Dec  7 2015 mimi.vx@gmail.com
- update to 3.1.6
  * drop dependency on happy
* Sun Nov 29 2015 mimi.vx@gmail.com
- update to 3.1.5
- drop alex-3.1.4-ghc-7.10.patch, merged by upstream
  * Generate less warning-laden code, and suppress other warnings.
  * Bug fixes.
* Wed May 13 2015 mimi.vx@gmail.com
- add alex-3.1.4-ghc-7.10.patch
  * temporary disable tests
* Fri Apr 10 2015 mimi.vx@gmail.com
- update to 3.1.4
  * Add Applicative/Functor instances for GHC 7.10
* Mon Sep  8 2014 peter.trommler@ohm-hochschule.de
- update to 3.1.3
  * fix ghc 7.8 builds
  * needed by Haskell Platform 2014.2.0.0
* Tue Sep  2 2014 peter.trommler@ohm-hochschule.de
- package examples
- cleanup spec file
* Fri Aug 22 2014 peter.trommler@ohm-hochschule.de
- enable PowerPC builds
* Tue May  7 2013 peter.trommler@ohm-hochschule.de
- update to 3.0.5 from upstream
  * performance improvement with certain grammars ~30%%
- part of Haskell Platform 2013.2
* Sat Nov 17 2012 peter.trommler@ohm-hochschule.de
- service localonly for Factory submission
* Mon Oct  1 2012 peter.trommler@ohm-hochschule.de
- update to 3.0.2 from upstream
- needed by Haskell Platform 2012.4.0.0
* Mon Jun  4 2012 peter.trommler@ohm-hochschule.de
- update to 3.0.1 from upstream
  * Unicode support (contributed mostly by Jean-Philippe Bernardy,
    with help from Alan Zimmerman).
  * An Alex lexer now takes a UTF-8 encoded byte sequence as input
    (see Section 5.1, “Unicode and UTF-8”. If you are using the
    "basic" wrapper or one of the other wrappers that takes a
    Haskell String as input, the string is automatically encoded
    into UTF-8 by Alex. If your input is a ByteString, you are
    responsible for ensuring that the input is UTF-8 encoded. The
    old 8-bit behaviour is still available via the --latin1
    option.
  * Alex source files are asumed to be in UTF-8, like Haskell
    source files. The lexer specification can use Unicode
    characters and ranges.
  * alexGetChar is renamed to alexGetByte in the generated code.
  * There is a new option, --latin1, that restores the old
    behaviour.
  * Alex now does DFA minimization, which helps to reduce the size
    of the generated tables, especially for lexers that use Unicode.
- dropped patch alex-2.3.5-generate-man-page.patch
- required by Haskell Platform 2012.2.0.0
* Mon May  7 2012 peter.trommler@ohm-hochschule.de
- add patch to enable man page generation
- generate, install and package man page alex.1
* Thu Dec 29 2011 peter.trommler@ohm-hochschule.de
- Clean up install section
- Add three word to description to make rpmlint happier
* Wed Dec 28 2011 peter.trommler@ohm-hochschule.de
- Adjusted version for platform 2011.4
* Sat Dec 10 2011 peter.trommler@ohm-hochschule.de
- Added /usr/share/alex-3.0.1 files
- Fixed file owner
- Deleted additional LICENSE file
* Mon Dec  5 2011 peter.trommler@ohm-hochschule.de
- Added QuickCheck BR
* Sat Nov 19 2011 peter.trommler@ohm-hochschule.de
- enabled i586 build
* Tue Oct 11 2011 peter.trommler@ohm-hochschule.de
- created new package
